X-Git-Url: https://git.p6c8.net/jirafeau.git/blobdiff_plain/60530d95ccf26f833db80b08c2a0a456f69e3aad..803190432fb705b53c37c403dba36d2c5a01f8c3:/tos.php?ds=sidebyside

diff --git a/tos.php b/tos.php
index 111916d..313f0da 100644
--- a/tos.php
+++ b/tos.php
@@ -1,43 +1,37 @@
-<?php
-/*
- *  Jirafeau, your web file repository
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
- */
-
-define ('JIRAFEAU_ROOT', dirname (__FILE__) . '/');
-require (JIRAFEAU_ROOT . 'lib/config.original.php');
-require (JIRAFEAU_ROOT . 'lib/settings.php');
-require (JIRAFEAU_ROOT . 'lib/functions.php');
-require (JIRAFEAU_ROOT . 'lib/lang.php');
-require (JIRAFEAU_ROOT . 'lib/template/header.php');
-
-$url = $cfg['web_root'] . 'tos.php';
-$org = "[THIS WEBSITE]";
-$contact = "
-By email:
-    contact@[THIS WEBSITE]
-";
-
-include (JIRAFEAU_ROOT . 'tos_text.php');
-
-echo '<h2>Terms of Service</h2>';
-echo '<div>';
-echo '<textarea readonly="readonly" rows="210" cols="80">';
-echo $tos;
-echo '</textarea>';
-echo '<p>This license text is under <a href="http://creativecommons.org/licenses/by/3.0/">Creative Commons - Attribution 3.0 Unported</a>.</p><p>It has been based on this work: <a href="http://opensource.org/ToS">http://opensource.org/ToS</a></p>';
-echo '</div>';
-require (JIRAFEAU_ROOT . 'lib/template/footer.php');
-?>
+<?php
+/*
+ *  Jirafeau, your web file repository
+ *
+ *  This program is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Affero General Public License as
+ *  published by the Free Software Foundation, either version 3 of the
+ *  License, or (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Affero General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Affero General Public License
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
+define('JIRAFEAU_ROOT', dirname(__FILE__) . '/');
+
+require(JIRAFEAU_ROOT . 'lib/settings.php');
+require(JIRAFEAU_ROOT . 'lib/functions.php');
+require(JIRAFEAU_ROOT . 'lib/lang.php');
+
+// Read ToS template
+if (is_readable(JIRAFEAU_ROOT . 'lib/tos.local.txt')) {
+    $content = file_get_contents(JIRAFEAU_ROOT . 'lib/tos.local.txt');
+} else {
+    $content = file_get_contents(JIRAFEAU_ROOT . 'lib/tos.original.txt');
+}
+
+// Replace markers and print ToS
+require(JIRAFEAU_ROOT . 'lib/template/header.php');
+
+echo '<div>' . jirafeau_replace_markers($content, true) . '</div>';
+
+require(JIRAFEAU_ROOT . 'lib/template/footer.php');